==> jc-1.4.0.tar.gz: java/awt/Cursor.h <==
// public class java.awt.Cursor

// class file dependencies
// @dep_class 6b950b4cca941574 java_awt_Cursor
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_Cursor_H_
#define _JC_java_awt_Cursor_H_

// Forward structure declarations
struct _jc_java_awt_Cursor$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_Cursor$sub_refs	_jc_java_awt_Cursor$sub_refs;
typedef struct _jc_java_awt_Cursor$sub_nonrefs	_jc_java_awt_Cursor$sub_nonrefs;
typedef struct _jc_java_awt_Cursor$refs	_jc_java_awt_Cursor$refs;
typedef struct _jc_java_awt_Cursor$nonrefs	_jc_java_awt_Cursor$nonrefs;
typedef struct _jc_java_awt_Cursor$object	_jc_java_awt_Cursor$object;

typedef struct _jc_java_awt_Cursor$fields_struct	_jc_java_awt_Cursor$fields_struct;
typedef const struct _jc_java_awt_Cursor$vmethods	_jc_java_awt_Cursor$vmethods;
typedef const struct _jc_java_awt_Cursor$vtable	_jc_java_awt_Cursor$vtable;
typedef const struct _jc_java_awt_Cursor$vtype	_jc_java_awt_Cursor$vtype;

// Class fields structure
struct _jc_java_awt_Cursor$fields_struct {
	_jc_object_array	*predefined;
	jlong	serialVersionUID;
	jint	CROSSHAIR__5fCURSOR;
	jint	CUSTOM__5fCURSOR;
	jint	DEFAULT__5fCURSOR;
	jint	E__5fRESIZE__5fCURSOR;
	jint	HAND__5fCURSOR;
	jint	MOVE__5fCURSOR;
	jint	NE__5fRESIZE__5fCURSOR;
	jint	NW__5fRESIZE__5fCURSOR;
	jint	N__5fRESIZE__5fCURSOR;
	jint	PREDEFINED__5fCOUNT;
	jint	SE__5fRESIZE__5fCURSOR;
	jint	SW__5fRESIZE__5fCURSOR;
	jint	S__5fRESIZE__5fCURSOR;
	jint	TEXT__5fCURSOR;
	jint	WAIT__5fCURSOR;
	jint	W__5fRESIZE__5fCURSOR;
};
extern _jc_java_awt_Cursor$fields_struct _jc_java_awt_Cursor$class_fields;

// Constructors
extern void _jc_java_awt_Cursor$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_Cursor$object *, jint);
extern void _jc_java_awt_Cursor$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_awt_Cursor$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_awt_Cursor$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_java_awt_Cursor$object *);
extern jint _jc_java_awt_Cursor$method$getType$74c20eac6b18d047(_jc_env *, struct _jc_java_awt_Cursor$object *);
extern struct _jc_java_lang_String$object *_jc_java_awt_Cursor$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_awt_Cursor$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_Cursor$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_java_awt_Cursor$method_info$getType$74c20eac6b18d047;
extern _jc_method _jc_java_awt_Cursor$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_java_awt_Cursor$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_awt_Cursor$object *_jc_java_awt_Cursor$method$getDefaultCursor$bb3555635a027420(_jc_env *);
extern struct _jc_java_awt_Cursor$object *_jc_java_awt_Cursor$method$getPredefinedCursor$a6866a5256a255b3(_jc_env *, jint);
extern struct _jc_java_awt_Cursor$object *_jc_java_awt_Cursor$method$getSystemCustomCursor$85fbb597f03bbfd0(_jc_env *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_awt_Cursor$vmethods {
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_java_awt_Cursor$object *);
	jint	(*getType$74c20eac6b18d047)(_jc_env *, struct _jc_java_awt_Cursor$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_awt_Cursor$object *);
};

// Vtable
struct _jc_java_awt_Cursor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Cursor$vmethods	java_awt_Cursor;
};

// Vtype
struct _jc_java_awt_Cursor$vtype {
	_jc_type			type;
	_jc_java_awt_Cursor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Cursor$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_java_awt_Cursor$refs {
    _jc_java_awt_Cursor$sub_refs	java_awt_Cursor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Cursor$sub_nonrefs {
	jint	type;
};

// Non-reference instance fields (object)
struct _jc_java_awt_Cursor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Cursor$sub_nonrefs	java_awt_Cursor;
};

// Object instance structure
struct _jc_java_awt_Cursor$object {
	_jc_java_awt_Cursor$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Cursor$vtype	*vtype;
	_jc_java_awt_Cursor$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Cursor$vtype _jc_java_awt_Cursor$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Cursor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Cursor$class_object;

#endif	/* _JC_java_awt_Cursor_H_ */

==> jc-1.4.6.tar.gz: java/awt/Cursor.h <==
// public class java.awt.Cursor

// class file dependencies
// @dep_class 6b950b4cca941574 java_awt_Cursor
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_Cursor_H_
#define _JC_java_awt_Cursor_H_

// Forward structure declarations
struct _jc_java_awt_Cursor$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_Cursor$sub_refs	_jc_java_awt_Cursor$sub_refs;
typedef struct _jc_java_awt_Cursor$sub_nonrefs	_jc_java_awt_Cursor$sub_nonrefs;
typedef struct _jc_java_awt_Cursor$refs	_jc_java_awt_Cursor$refs;
typedef struct _jc_java_awt_Cursor$nonrefs	_jc_java_awt_Cursor$nonrefs;
typedef struct _jc_java_awt_Cursor$object	_jc_java_awt_Cursor$object;

typedef struct _jc_java_awt_Cursor$fields_struct	_jc_java_awt_Cursor$fields_struct;
typedef const struct _jc_java_awt_Cursor$vmethods	_jc_java_awt_Cursor$vmethods;
typedef const struct _jc_java_awt_Cursor$vtable	_jc_java_awt_Cursor$vtable;
typedef const struct _jc_java_awt_Cursor$vtype	_jc_java_awt_Cursor$vtype;

// Class fields structure
struct _jc_java_awt_Cursor$fields_struct {
	_jc_object_array	*predefined;
	jlong	serialVersionUID;
	jint	CROSSHAIR__5fCURSOR;
	jint	CUSTOM__5fCURSOR;
	jint	DEFAULT__5fCURSOR;
	jint	E__5fRESIZE__5fCURSOR;
	jint	HAND__5fCURSOR;
	jint	MOVE__5fCURSOR;
	jint	NE__5fRESIZE__5fCURSOR;
	jint	NW__5fRESIZE__5fCURSOR;
	jint	N__5fRESIZE__5fCURSOR;
	jint	PREDEFINED__5fCOUNT;
	jint	SE__5fRESIZE__5fCURSOR;
	jint	SW__5fRESIZE__5fCURSOR;
	jint	S__5fRESIZE__5fCURSOR;
	jint	TEXT__5fCURSOR;
	jint	WAIT__5fCURSOR;
	jint	W__5fRESIZE__5fCURSOR;
};
extern _jc_java_awt_Cursor$fields_struct _jc_java_awt_Cursor$class_fields;

// Constructors
extern void _jc_java_awt_Cursor$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_Cursor$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_awt_Cursor$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_awt_Cursor$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_awt_Cursor$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_java_awt_Cursor$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_Cursor$method$getType$74c20eac6b18d047(_jc_env *, struct _jc_java_awt_Cursor$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_awt_Cursor$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_awt_Cursor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_Cursor$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_java_awt_Cursor$method_info$getType$74c20eac6b18d047;
extern _jc_method _jc_java_awt_Cursor$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_java_awt_Cursor$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Cursor$object *_jc_java_awt_Cursor$method$getDefaultCursor$bb3555635a027420(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Cursor$object *_jc_java_awt_Cursor$method$getPredefinedCursor$a6866a5256a255b3(_jc_env *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Cursor$object *_jc_java_awt_Cursor$method$getSystemCustomCursor$85fbb597f03bbfd0(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_Cursor$vmethods {
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_java_awt_Cursor$object *) _JC_JCNI_ATTR;
	jint	(*getType$74c20eac6b18d047)(_jc_env *, struct _jc_java_awt_Cursor$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_awt_Cursor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_Cursor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Cursor$vmethods	java_awt_Cursor;
};

// Vtype
struct _jc_java_awt_Cursor$vtype {
	_jc_type			type;
	_jc_java_awt_Cursor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Cursor$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_java_awt_Cursor$refs {
    _jc_java_awt_Cursor$sub_refs	java_awt_Cursor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Cursor$sub_nonrefs {
	jint	type;
};

// Non-reference instance fields (object)
struct _jc_java_awt_Cursor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Cursor$sub_nonrefs	java_awt_Cursor;
};

// Object instance structure
struct _jc_java_awt_Cursor$object {
	_jc_java_awt_Cursor$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Cursor$vtype	*vtype;
	_jc_java_awt_Cursor$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Cursor$vtype _jc_java_awt_Cursor$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Cursor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Cursor$class_object;

#endif	/* _JC_java_awt_Cursor_H_ */
